.. importopoi documentation master file, created by
   sphinx-quickstart on Tue Jul 13 21:11:42 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

importopoi: Visualising module connections within a Python package
==================================================================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    api
    overview


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
